@@ -27,9 +27,9 @@
 
 #include <list>
 #include <gtkmm/widget.h>
-#include "nmv-object.h"
+#include "common/nmv-object.h"
+#include "common/nmv-safe-ptr-utils.h"
 #include "nmv-i-debugger.h"
-#include "nmv-safe-ptr-utils.h"
 
 namespace Gtk {
 class UIManager;
@@ -49,16 +49,15 @@ class NEMIVER_API BreakpointsView : public nemiver::common::Object {
 
 public:
 
-    BreakpointsView (IWorkbench& a_workbench, IPerspective& a_perspective) ;
+    BreakpointsView (IWorkbench& a_workbench, IPerspective& a_perspective, IDebuggerSafePtr& a_debugger) ;
     virtual ~BreakpointsView () ;
     Gtk::Widget& widget () const ;
     void set_breakpoints
                 (const std::map<int, IDebugger::BreakPoint> &a_breakpoints) ;
     void clear () ;
+    void re_init () ;
     sigc::signal<void,
                  const IDebugger::BreakPoint&>& go_to_breakpoint_signal () const ;
-    sigc::signal<void,
-                 const IDebugger::BreakPoint&>& delete_breakpoint_signal () const ;
 
 };//end BreakpointsView
 
